@@ -27,7 +27,6 @@ from calibre import as_unicode, browser, random_user_agent, xml_replace_entities
 from calibre.ebooks.metadata import check_isbn
 from calibre.ebooks.metadata.book.base import Metadata
 from calibre.ebooks.metadata.sources.base import Option, Source, fixauthors, fixcase
-from calibre.ebooks.oeb.base import urlquote
 from calibre.utils.icu import lower as icu_lower
 from calibre.utils.localization import canonicalize_lang
 from calibre.utils.random_ua import accept_header_for_ua
@@ -51,6 +50,7 @@ def sort_matches_preferring_kindle_editions(matches):
 
 
 def iri_quote_plus(url):
+    from calibre.ebooks.oeb.base import urlquote
     ans = urlquote(url)
     if isinstance(ans, bytes):
         ans = ans.decode('utf-8')
@@ -1090,7 +1090,7 @@ class Worker(Thread):  # Get details {{{
 class Amazon(Source):
 
     name = 'Amazon.com'
-    version = (1, 3, 12)
+    version = (1, 3, 13)
     minimum_calibre_version = (2, 82, 0)
     description = _('Downloads metadata and covers from Amazon')
 
@@ -1568,8 +1568,8 @@ class Amazon(Source):
         elif server == 'google':
             urlproc, sfunc = se.google_url_processor, se.google_search
         else:  # auto or unknown
-            # urlproc, sfunc = se.google_url_processor, se.google_search
-            urlproc, sfunc = se.bing_url_processor, se.bing_search
+            urlproc, sfunc = se.google_url_processor, se.google_search
+            # urlproc, sfunc = se.bing_url_processor, se.bing_search
         try:
             results, qurl = sfunc(terms, site, log=log, br=br, timeout=timeout)
         except HTTPError as err:
@@ -1734,8 +1734,6 @@ class Amazon(Source):
                           identifiers=identifiers)
             if abort.is_set():
                 return
-            if abort.is_set():
-                return
             results = []
             while True:
                 try:
