@@ -7,6 +7,7 @@ import re
 from collections import namedtuple
 from contextlib import suppress
 from functools import lru_cache, partial
+from math import ceil
 
 from qt.core import (
     QAction,
@@ -24,6 +25,7 @@ from qt.core import (
     QPalette,
     QPen,
     QPixmap,
+    QPoint,
     QPropertyAnimation,
     QRect,
     QSize,
@@ -38,7 +40,7 @@ from qt.core import (
 )
 
 from calibre import fit_image, sanitize_file_name
-from calibre.constants import config_dir, iswindows
+from calibre.constants import DEBUG, config_dir, iswindows
 from calibre.db.constants import DATA_DIR_NAME, DATA_FILE_PATTERN, NO_SEARCH_LINK, RESOURCE_URL_SCHEME
 from calibre.ebooks import BOOK_EXTENSIONS
 from calibre.ebooks.metadata.book.base import Metadata, field_metadata
@@ -579,11 +581,13 @@ def add_item_specific_entries(menu, data, book_info, copy_menu, search_menu):
                 v = data.get('original_value') or data.get('value')
                 copy_menu.addAction(QIcon.ic('edit-copy.png'), _('The text: {}').format(v),
                                         lambda: QApplication.instance().clipboard().setText(v))
-            if field != 'size':
-                ac = book_info.remove_item_action
-                ac.data = (field, remove_value, book_id)
-                ac.setText(_('Remove %s from this book') % escape_for_menu(remove_name or data.get('original_value') or value))
-                menu.addAction(ac)
+            if field not in ('size', 'id', 'last_modified', 'sort', 'series_sort', 'uuid', 'author_sort'):
+                fm = get_gui().current_db.new_api.field_metadata.get(field) or {}
+                if fm.get('datatype') != 'composite':
+                    ac = book_info.remove_item_action
+                    ac.data = (field, remove_value, book_id)
+                    ac.setText(_('Remove %s from this book') % escape_for_menu(remove_name or data.get('original_value') or value))
+                    menu.addAction(ac)
             # See if we need to add a click associated link menu line
             link_map = get_gui().current_db.new_api.get_all_link_maps_for_book(data.get('book_id', -1))
             link = link_map.get(field, {}).get(value)
@@ -672,7 +676,30 @@ def create_copy_links(menu, data=None):
 
 
 def details_context_menu_event(view, ev, book_info, add_popup_action=False, edit_metadata=None):
-    url = view.anchorAt(ev.pos())
+    if not (url := view.anchorAt(ev.pos())) and (dpr := ceil(view.devicePixelRatio())) > 1:
+        # Attempt to compensate for high density displays. When tabbing into an
+        # anchor (URL) Qt picks a point on the outer right edge for the
+        # position. Theory: on high-resolution displays, the outer right edge
+        # can be a few real pixels to the right of the bounding box for the
+        # anchor. As a result, Qt's chosen point isn't in the box. Compensate
+        # for that by moving the position slightly to the left and see if an
+        # anchor is found and, if so, use it. When back-tabbing into an anchor,
+        # Qt uses the left hand side of the bounding box, which isn't affected
+        # by high density. Note that this compensation could cause Qt to find
+        # an anchor when the user clicks in narrow empty space between anchors.
+        # I think this is ok because exact pixel mouse clicking is extremely
+        # difficult.
+        p = ev.pos()
+        p += QPoint(-dpr, 0)
+        url = view.anchorAt(p)
+        if DEBUG:
+            def pnt_to_str(p):
+                return f'{p.x()}, {p.y()}'
+            def rect_to_str(p):
+                return f'{p.x()}, {p.y()}, {p.width()}, {p.height()}'
+            print(f'BD ctxt menu pos. ev.pos: ({pnt_to_str(ev.pos())}), '
+                f'npos: ({pnt_to_str(p)}), cursor rect: ({rect_to_str(view.cursorRect())}), '
+                f'has url: {bool(url)}')
     menu = QMenu(view)
     copy_menu = menu.addMenu(QIcon.ic('edit-copy.png'), _('Copy'))
     copy_menu.addAction(QIcon.ic('edit-copy.png'), _('All book details'), partial(copy_all, view))
