@@ -243,7 +243,7 @@ class BooksModel(QAbstractTableModel):  # {{{
         self.bool_yes_icon = QIcon.ic('ok.png').pixmap(icon_height)
         self.bool_no_icon = QIcon.ic('list_remove.png').pixmap(icon_height)
         self.bool_blank_icon = QIcon.ic('blank.png').pixmap(icon_height)
-        # Qt auto-scales marked icon correctly, so we dont need to do it (and
+        # Qt auto-scales marked icon correctly, so we don't need to do it (and
         # remember that the cover grid view needs a larger version of the icon,
         # anyway)
         self.marked_icon = QIcon.ic('marked.png')
@@ -1021,6 +1021,13 @@ class BooksModel(QAbstractTableModel):  # {{{
         # we will get asked to display columns we don't know about. Must test for this.
         if col >= len(self.column_to_dc_map) or col < 0:
             return None
+        try:
+            return self.actual_data(index, role, col)
+        except Exception:
+            import traceback
+            traceback.print_exc()
+
+    def actual_data(self, index, role, col):
         if role == Qt.ItemDataRole.DisplayRole:
             rules = self.db_prefs['column_icon_rules']
             if rules:
