@@ -26,7 +26,6 @@ Launch the Graphical User Interface
 
 
 class GarbageCollector(QObject):
-
     '''
     Disable automatic garbage collection and instead collect manually
     every INTERVAL milliseconds.
@@ -118,7 +117,7 @@ class MainWindow(QMainWindow):
     def native_menubar(self):
         return self.___menu_bar
 
-    def __init__(self, opts, parent=None, disable_automatic_gc=False):
+    def __init__(self, opts=None, parent=None, disable_automatic_gc=False):
         QMainWindow.__init__(self, parent)
         self.display_unhandled_exception.connect(self.unhandled_exception, type=Qt.ConnectionType.QueuedConnection)
         if disable_automatic_gc:
@@ -234,7 +233,7 @@ class MainWindow(QMainWindow):
                     return
             except Exception:
                 traceback.print_exc()
-            msg = '<b>%s</b>:'%exc_type.__name__ + prepare_string_for_xml(as_unicode(value))
+            msg = f'<b>{exc_type.__name__}</b>:' + prepare_string_for_xml(as_unicode(value))
             error_dialog(self, _('Unhandled exception'), msg, det_msg=fe,
                     show=True)
         except BaseException:
