@@ -55,8 +55,8 @@ class Connection(sqlite.Connection):
 def _connect(path):
     if isinstance(path, str):
         path = path.encode('utf-8')
-    conn =  sqlite.connect(path, factory=Connection, detect_types=sqlite.PARSE_DECLTYPES|sqlite.PARSE_COLNAMES)
-    conn.row_factory = lambda cursor, row : list(row)
+    conn = sqlite.connect(path, factory=Connection, detect_types=sqlite.PARSE_DECLTYPES|sqlite.PARSE_COLNAMES)
+    conn.row_factory = lambda cursor, row: list(row)
     conn.create_aggregate('concat', 1, Concatenate)
     title_pat = re.compile(r'^(A|The|An)\s+', re.IGNORECASE)
 
@@ -814,18 +814,18 @@ ALTER TABLE books ADD COLUMN isbn TEXT DEFAULT "" COLLATE NOCASE;
         i = 0
         while True:
             i += 1
-            func = getattr(LibraryDatabase, 'upgrade_version%d'%i, None)
+            func = getattr(LibraryDatabase, f'upgrade_version{i}', None)
             if func is None:
                 break
             if self.user_version == i:
-                print('Upgrading database from version: %d'%i)
+                print(f'Upgrading database from version: {i}')
                 func(self.conn)
 
     def close(self):
-        #        global _lock_file
-        #        _lock_file.close()
-        #        os.unlink(_lock_file.name)
-        #        _lock_file = None
+        # global _lock_file
+        # _lock_file.close()
+        # os.unlink(_lock_file.name)
+        # _lock_file = None
         self.conn.close()
 
     @property
@@ -841,16 +841,16 @@ ALTER TABLE books ADD COLUMN isbn TEXT DEFAULT "" COLLATE NOCASE;
         Rebuild self.data and self.cache. Filter results are lost.
         '''
         FIELDS = {
-                  'title'        : 'sort',
-                  'authors'      : 'author_sort',
-                  'publisher'    : 'publisher',
-                  'size'         : 'size',
-                  'date'         : 'timestamp',
-                  'timestamp'    : 'timestamp',
-                  'formats'      : 'formats',
-                  'rating'       : 'rating',
-                  'tags'         : 'tags',
-                  'series'       : 'series',
+                  'title'    : 'sort',
+                  'authors'  : 'author_sort',
+                  'publisher': 'publisher',
+                  'size'     : 'size',
+                  'date'     : 'timestamp',
+                  'timestamp': 'timestamp',
+                  'formats'  : 'formats',
+                  'rating'   : 'rating',
+                  'tags'     : 'tags',
+                  'series'   : 'series',
                  }
         field = FIELDS[sort_field]
         order = 'ASC'
@@ -1057,15 +1057,15 @@ ALTER TABLE books ADD COLUMN isbn TEXT DEFAULT "" COLLATE NOCASE;
                 self.conn.get('SELECT id, name FROM series')]
 
     def series_name(self, series_id):
-        return self.conn.get('SELECT name FROM series WHERE id=%d'%series_id,
+        return self.conn.get(f'SELECT name FROM series WHERE id={series_id}',
                 all=False)
 
     def author_name(self, author_id):
-        return self.conn.get('SELECT name FROM authors WHERE id=%d'%author_id,
+        return self.conn.get(f'SELECT name FROM authors WHERE id={author_id}',
                 all=False)
 
     def tag_name(self, tag_id):
-        return self.conn.get('SELECT name FROM tags WHERE id=%d'%tag_id,
+        return self.conn.get(f'SELECT name FROM tags WHERE id={tag_id}',
                 all=False)
 
     def all_authors(self):
@@ -1102,12 +1102,12 @@ ALTER TABLE books ADD COLUMN isbn TEXT DEFAULT "" COLLATE NOCASE;
         if len(ids) > 50000:
             return True
         if len(ids) == 1:
-            ids = '(%d)'%ids[0]
+            ids = f'({ids[0]})'
         else:
             ids = repr(ids)
-        return self.conn.get('''
-            SELECT data FROM conversion_options WHERE book IN %s AND
-        format=? LIMIT 1'''%(ids,), (format,), all=False) is not None
+        return self.conn.get(f'''
+            SELECT data FROM conversion_options WHERE book IN {ids} AND
+        format=? LIMIT 1''', (format,), all=False) is not None
 
     def delete_conversion_options(self, id, format, commit=True):
         self.conn.execute('DELETE FROM conversion_options WHERE book=? AND format=?',
@@ -1385,7 +1385,7 @@ ALTER TABLE books ADD COLUMN isbn TEXT DEFAULT "" COLLATE NOCASE;
         yield from feeds
 
     def get_feed(self, id):
-        return self.conn.get('SELECT script FROM feeds WHERE id=%d'%id,
+        return self.conn.get(f'SELECT script FROM feeds WHERE id={id}',
                 all=False)
 
     def update_feed(self, id, script, title):
@@ -1462,13 +1462,13 @@ ALTER TABLE books ADD COLUMN isbn TEXT DEFAULT "" COLLATE NOCASE;
 
 class SearchToken:
 
-    FIELD_MAP = {'title'       : 1,
-                  'author'      : 2,
-                  'publisher'   : 3,
-                  'tag'         : 7,
-                  'comments'    : 8,
-                  'series'      : 9,
-                  'format'      : 13,
+    FIELD_MAP = {'title'     : 1,
+                  'author'   : 2,
+                  'publisher': 3,
+                  'tag'      : 7,
+                  'comments' : 8,
+                  'series'   : 9,
+                  'format'   : 13,
                  }
 
     def __init__(self, text_token):
@@ -1504,11 +1504,11 @@ def text_to_tokens(text):
         text = match.group(1)
         OR = True
     tokens = []
-    quot = re.search('"(.*?)"', text)
+    quot = re.search(r'"(.*?)"', text)
     while quot:
         tokens.append(quot.group(1))
         text = text.replace('"'+quot.group(1)+'"', '')
-        quot = re.search('"(.*?)"', text)
+        quot = re.search(r'"(.*?)"', text)
     tokens += text.split(' ')
     ans = []
     for i in tokens:
