@@ -212,7 +212,7 @@ def ACQUISITION_ENTRY(book_id, updated, request_context):
         extra.append(comments)
     if extra:
         extra = html_to_lxml('\n'.join(extra))
-    ans = E.entry(TITLE(mi.title), E.author(E.name(authors_to_string(mi.authors))), ID('urn:uuid:' + mi.uuid), UPDATED(mi.last_modified),
+    ans = E.entry(TITLE(mi.title), E.author(E.name(authors_to_string(mi.authors))), ID('urn:uuid:' + (mi.uuid or '')), UPDATED(mi.last_modified),
                   E.published(mi.timestamp.isoformat()))
     if mi.pubdate and not is_date_undefined(mi.pubdate):
         ans.append(ans.makeelement(f'{{{DC_NS}}}date'))
