@@ -192,7 +192,7 @@ class SetGlobalsNode(Node):
 
 class StringCompareNode(Node):
     def __init__(self, line_number, operator, left, right):
-        Node.__init__(self, line_number, 'comparision: ' + operator)
+        Node.__init__(self, line_number, 'comparison: ' + operator)
         self.node_type = self.NODE_COMPARE_STRING
         self.operator = operator
         self.left = left
@@ -2035,7 +2035,7 @@ class ValidateFormatter(TemplateFormatter):
 
     def validate(self, x):
         from calibre.ebooks.metadata.book.base import Metadata
-        return self.safe_format(x, {}, 'VALIDATE ERROR', Metadata(''))
+        return self.unsafe_format(x, {}, 'VALIDATE ERROR', Metadata(''))
 
 
 validation_formatter = ValidateFormatter()
