@@ -1556,6 +1556,8 @@ exec_module(PyObject *m) {
     A(SHGFP_TYPE_CURRENT);
     A(SHGFP_TYPE_DEFAULT);
     A(PIPE_ACCESS_INBOUND);
+    A(PIPE_ACCESS_OUTBOUND);
+    A(PIPE_ACCESS_DUPLEX);
     A(FILE_FLAG_FIRST_PIPE_INSTANCE);
     A(PIPE_TYPE_BYTE);
     A(PIPE_READMODE_BYTE);
